@@ -39,7 +39,7 @@ use WebDyne::Util;
 
 #  Version information
 #
-$VERSION='2.016';
+$VERSION='2.017';
 
 
 #  Debug load
@@ -267,6 +267,11 @@ sub compile {
     #
     $tree_or->eof();
     $html_fh->close();
+    
+    
+    #  Set flag if we have seen <api> tags
+    #
+    my $api_fg=$tree_or->{'_api_webdyne'};
 
 
     #  Elementify
@@ -286,8 +291,8 @@ sub compile {
         return err($close_cr->());
     };
     debug("meta after parse %s", Dumper(\%meta));
-
-
+    
+    
     #  Now destroy the HTML::Treebuilder object, or else mem leak occurs
     #
     $close_cr->();
@@ -335,6 +340,29 @@ sub compile {
                 }) || return err();
         }
     }
+    
+    
+    #  If <api> tag used in page compress down to just the <api> nodes and throw
+    #  everything else away.
+    #
+    if ($api_fg) {
+    
+        #  Find all the api nodes
+        #
+        my $api_ar=$self->find_node({
+            data_ar	=> $data_ar,
+            tag		=> 'api',
+            all_fg	=> 1
+        });
+        
+        
+        #  And make a new data_ar structure to hold it, throwing everything else
+        #  in the bin
+        #
+        $data_ar=[undef, undef, $api_ar];
+
+    }
+    
 
     #  Construct final webdyne container
     #
@@ -1001,9 +1029,9 @@ sub optimise_two {
 
 
         }
-        elsif (!$data_uppr_ar) {
-
-
+        elsif (!$data_uppr_ar && $html_tag) {
+        
+        
             #  Must be at top node, as nothing above us,
             #  get start and end tag methods
             #
@@ -1060,6 +1088,14 @@ sub optimise_two {
             $data_uppr_ar=\@data_new;
 
 
+        }
+        elsif (!$data_uppr_ar && !$html_tag) {
+        
+        
+            #  Special case generated by page with <api> tags, means we're not going to wrap in <html>
+            #
+            $data_uppr_ar=$data_ar->[WEBDYNE_NODE_CHLD_IX];
+            
         }
 
 
